%bcond_with doc
%bcond_with check

Summary:       An interactive computing environment for Python
Name:          ipython
Version:       8.32.0
Release:       %mkrel 1
License:       BSD
Group:         Development/Python
Url:           https://ipython.org/
Source0:       %{pypi_source}
BuildArch:     noarch
BuildRequires: pyproject-rpm-macros
BuildRequires: python3-devel
Provides:      python3-ipython = %{version}-%{release}
%{?python_provide:%python_provide python3-%{name}}

%description
IPython provides a rich toolkit to help you make the most out of using
Python interactively. Its main components are:

* A powerful interactive Python shell
* A Jupyter kernel to work with Python code in Jupyter notebooks and
  other interactive frontends.

The enhanced interactive Python shell has the following main features:

* Comprehensive object introspection.
* Input history, persistent across sessions.
* Caching of output results during a session with automatically generated references.
* Extensible tab completion, with support by default for completion of python variables
  and keywords, filenames and function keywords.
* Extensible system of ‘magic’ commands for controlling the environment and performing
  many tasks related either to IPython or the operating system.
* A rich configuration system with easy switching between different setups
  (simpler than changing $PYTHONSTARTUP environment variables every time).
* Session logging and reloading.
* Extensible syntax processing for special purpose situations.
* Access to the system shell with user-extensible alias system.
* Easily embeddable in other Python programs and GUIs.
* Integrated access to the pdb debugger and the Python profiler.

%pyproject_extras_subpkg -n python3-%{name} notebook

%prep
%autosetup -p1 -n %{name}-%{version}

%generate_buildrequires
%pyproject_buildrequires %{?with_doc:-x doc} %{?with_check:-x test}

%build
%pyproject_wheel

%if %{with doc}
pushd docs
PYTHONPATH=.. make html SPHINXBUILD='sphinx-build-3 -D intersphinx_timeout=1'
mkdir -p build/html/
rm -rf build/html/.buildinfo
popd
%endif

%install
%pyproject_install
%pyproject_save_files IPython

# move the manpage to ipython3
mv %{buildroot}%{_mandir}/man1/ipython{,3}.1

%if %{with check}
%check
# Ensure that the user's .pythonrc.py is not invoked during any tests.
export PYTHONSTARTUP=""
# Fedora's Koji builders can be slow, especially on arms, we scale timeouts 4 times
export IPYTHON_TESTING_TIMEOUT_SCALE=4
# To prevent _pytest.pathlib.ImportPathMismatchError, we are
# testing directly in buildroot
pushd %{buildroot}%{python3_sitelib}/IPython
%pytest -k "not test_latex_to_png_color"
rm -rf .pytest_cache
popd
%else
rm -r %{buildroot}%{python3_sitelib}/IPython/*/tests
sed -i -e '/\/tests\//d' -e '/\/tests$/d' %{pyproject_files}
%endif

%files -f %{pyproject_files}
%doc README.rst
%if %{with doc}
%doc docs/build/html
%endif
%{_bindir}/ip*
%{_mandir}/man1/*


%changelog
* Mon Mar 03 2025 daviddavid <daviddavid> 8.32.0-1.mga10
+ Revision: 2159506
- new version: 8.32.0

* Sun Mar 02 2025 wally <wally> 8.19.0-2.mga10
+ Revision: 2156397
- rebuild for python3.13

* Mon Dec 25 2023 wally <wally> 8.19.0-1.mga10
+ Revision: 2021448
- new version 8.19.0
- build without docs and tests for now due to a circular deps
- rebuild for py3.12

* Fri Oct 20 2023 papoteur <papoteur> 8.16.1-1.mga10
+ Revision: 1999741
- new 8.16.1

* Sun Feb 19 2023 wally <wally> 8.10.0-2.mga9
+ Revision: 1944113
- ship html docs with the main pkg
- drop separate doc subpkg
- restore notebook extras pkg
- enable check

* Sat Feb 18 2023 papoteur <papoteur> 8.10.0-1.mga9
+ Revision: 1943952
- new 8.10.0
- port to pyproject
- add stack-data dependency and reorder them

* Tue Mar 29 2022 umeabot <umeabot> 7.31.1-2.mga9
+ Revision: 1833267
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tmb <tmb> 7.31.1-1.mga9
+ Revision: 1779495
- update to 7.31.1 (mga#29969)

* Sun Feb 13 2022 tmb <tmb> 7.22.0-2.mga9
+ Revision: 1774040
- rebuild for python 3.10

* Sun Apr 18 2021 daviddavid <daviddavid> 7.22.0-1.mga9
+ Revision: 1716597
- new version: 7.22.0

* Thu Mar 25 2021 daviddavid <daviddavid> 7.21.0-3.mga9
+ Revision: 1709726
- relax prompt-toolkit dependency

* Thu Mar 25 2021 daviddavid <daviddavid> 7.21.0-2.mga9
+ Revision: 1709716
- add ipython[notebook] extra subpackage

* Wed Mar 17 2021 wally <wally> 7.21.0-1.mga9
+ Revision: 1704040
- new version 7.21.0
- rebuild for python 3.9

* Tue Mar 02 2021 daviddavid <daviddavid> 7.20.0-1.mga9
+ Revision: 1696237
- new version: 7.20.0

* Sun Dec 06 2020 luigiwalser <luigiwalser> 7.19.0-1.mga8
+ Revision: 1653272
- 7.19.0

* Fri Sep 25 2020 luigiwalser <luigiwalser> 7.18.1-1.mga8
+ Revision: 1630130
- 7.18.1

* Tue Jun 09 2020 daviddavid <daviddavid> 7.15.0-1.mga8
+ Revision: 1591160
- new version: 7.15.0

* Tue Mar 31 2020 daviddavid <daviddavid> 7.13.0-1.mga8
+ Revision: 1562599
- new version: 7.13.0

* Thu Feb 20 2020 umeabot <umeabot> 7.12.0-2.mga8
+ Revision: 1546814
- Mageia 8 Mass Rebuild

* Wed Feb 05 2020 daviddavid <daviddavid> 7.12.0-1.mga8
+ Revision: 1487199
- new version: 7.12.0

* Fri Jan 03 2020 luigiwalser <luigiwalser> 7.10.2-1.mga8
+ Revision: 1475623
- 7.10.2

* Sat Nov 23 2019 daviddavid <daviddavid> 7.9.0-1.mga8
+ Revision: 1462297
- new version: 7.9.0

* Sat Oct 12 2019 daviddavid <daviddavid> 7.8.0-1.mga8
+ Revision: 1452053
- new version: 7.8.0

* Fri Sep 13 2019 tv <tv> 7.2.0-4.mga8
+ Revision: 1440502
- rebuild for python-3.8

* Mon Jan 07 2019 wally <wally> 7.2.0-3.mga7
+ Revision: 1351128
- add more requires

* Mon Jan 07 2019 wally <wally> 7.2.0-2.mga7
+ Revision: 1351101
- update requires
- require pygments

* Mon Jan 07 2019 wally <wally> 7.2.0-1.mga7
+ Revision: 1350856
- new version 7.2.0
- add bcond for doc build (from Fedora)
+ tv <tv>
- rebuild with python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 6.3.1-3.mga7
+ Revision: 1278880
- Mageia 7 Mass Rebuild

* Sun Jun 03 2018 luigiwalser <luigiwalser> 6.3.1-2.mga7
+ Revision: 1234371
- obsolete one more subpkg from wrongly imported python-ipython

* Wed Apr 25 2018 kekepower <kekepower> 6.3.1-1.mga7
+ Revision: 1222454
- Update to version 6.3.1
- Update BRs

* Tue Aug 08 2017 philippem <philippem> 6.1.0-3.mga7
+ Revision: 1138993
- rebuild using setuptools to generate requires

* Sun Aug 06 2017 tv <tv> 6.1.0-2.mga7
+ Revision: 1137827
- rename back as ipython as ipython2 is dead

* Sun Aug 06 2017 tv <tv> 6.1.0-1.mga7
+ Revision: 1137701
- new release
- it doesn't support py2 anymore

* Sat Aug 05 2017 pterjan <pterjan> 5.0.0-4.mga7
+ Revision: 1135229
- Rebuild for python 3.6

* Mon Jul 10 2017 akien <akien> 5.0.0-3.mga6
+ Revision: 1109654
- Fix upgrade conflicts as advised by Charles Edwards (mga#21223)

* Wed Mar 22 2017 philippem <philippem> 5.0.0-2.mga6
+ Revision: 1094270
- add requires on ipython-genutils mga#20544

* Tue Jul 19 2016 joequant <joequant> 5.0.0-1.mga6
+ Revision: 1042582
- upgrade to 5.0.0

* Fri Apr 22 2016 tv <tv> 4.2.0-2.mga6
+ Revision: 1005278
- fix upgrading python3-ipythonx

* Wed Apr 20 2016 philippem <philippem> 4.2.0-1.mga6
+ Revision: 1003789
- update to 4.2.0, add doc, make python3 version as default

* Sun Apr 17 2016 philippem <philippem> 4.1.2-1.mga6
+ Revision: 1003215
- update to 4.1.2, make Python3 as default, rename python3-ipython as ipython3

* Fri Dec 18 2015 luigiwalser <luigiwalser> 3.2.2-1.mga6
+ Revision: 911726
- 3.2.2 (fixes CVE-2015-7337)
- remove upstreamed patch 0

* Wed Oct 07 2015 tv <tv> 3.2.1-3.mga6
+ Revision: 887111
- rebuild for python 3.5

* Wed Sep 02 2015 philippem <philippem> 3.2.1-2.mga6
+ Revision: 872286
- security fix from upstream mga#16686

* Tue Jul 14 2015 philippem <philippem> 3.2.1-1.mga6
+ Revision: 853760
- fix mga#16373 update to 3.2.1

* Sun Jul 05 2015 joequant <joequant> 3.2.0-2.mga6
+ Revision: 850838
- add terminado as suggests

* Tue Jun 30 2015 joequant <joequant> 3.2.0-1.mga6
+ Revision: 848342
- upgrade to 3.2
+ luigiwalser <luigiwalser>
- 2.3.1

* Wed Oct 15 2014 umeabot <umeabot> 2.3.0-2.mga5
+ Revision: 742139
- Second Mageia 5 Mass Rebuild

* Wed Oct 08 2014 luigiwalser <luigiwalser> 2.3.0-1.mga5
+ Revision: 737598
- 2.3.0

* Sat Sep 27 2014 tv <tv> 2.2.0-4.mga5
+ Revision: 726524
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.2.0-3.mga5
+ Revision: 680560
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/
+ ovitters <ovitters>
- add gobject-introspection BR for typelib auto BR

* Sun Sep 14 2014 joequant <joequant> 2.2.0-2.mga5
+ Revision: 675217
- rebuild for dependencies

* Fri Aug 08 2014 philippem <philippem> 2.2.0-1.mga5
+ Revision: 661160
- update to 2.2.0

* Sat May 31 2014 pterjan <pterjan> 2.1.0-3.mga5
+ Revision: 629679
- Rebuild for new Python

* Sat May 31 2014 pterjan <pterjan> 2.1.0-2.mga5
+ Revision: 628266
- Rebuild for new Python

* Fri May 23 2014 luigiwalser <luigiwalser> 2.1.0-1.mga5
+ Revision: 625225
- 2.1.0

* Thu Apr 10 2014 philippem <philippem> 2.0.0-2.mga5
+ Revision: 613307
- add missing suggests for python3

* Thu Apr 03 2014 philippem <philippem> 2.0.0-1.mga5
+ Revision: 611437
- update to 2.0.0

* Sun Mar 16 2014 philippem <philippem> 1.2.1-2.mga5
+ Revision: 604190
- add Python3

* Wed Feb 26 2014 luigiwalser <luigiwalser> 1.2.1-1.mga5
+ Revision: 597331
- 1.2.1

* Fri Feb 14 2014 luigiwalser <luigiwalser> 1.2.0-1.mga5
+ Revision: 590999
- 1.2.0

* Tue Oct 22 2013 umeabot <umeabot> 1.1.0-3.mga4
+ Revision: 544806
- Mageia 4 Mass Rebuild

* Fri Oct 18 2013 malo <malo> 1.1.0-2.mga4
+ Revision: 519210
- fix suggests to jinja2 and tornado (patch by Daniel Napora)

* Tue Oct 15 2013 luigiwalser <luigiwalser> 1.1.0-1.mga4
+ Revision: 500286
- 1.1.0

* Mon Oct 14 2013 pterjan <pterjan> 1.0.0-2.mga4
+ Revision: 497820
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Aug 20 2013 luigiwalser <luigiwalser> 1.0.0-1.mga4
+ Revision: 468289
- 1.0.0

* Sun Aug 04 2013 joequant <joequant> 0.13.2-2.mga4
+ Revision: 463116
- redo spec
- suggest torando for ipython notebook

* Sun Apr 07 2013 luigiwalser <luigiwalser> 0.13.2-1.mga3
+ Revision: 408637
- 0.13.2

* Sat Jan 12 2013 umeabot <umeabot> 0.13.1-2.mga3
+ Revision: 354491
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 03 2013 luigiwalser <luigiwalser> 0.13.1-1.mga3
+ Revision: 338399
- 0.13.1

* Mon Oct 22 2012 dams <dams> 0.13-1.mga3
+ Revision: 309263
- new version 0.13

* Tue Sep 20 2011 lebedov <lebedov> 0.11-2.mga2
+ Revision: 146101
- Update to 0.11.

* Thu Apr 21 2011 ahmad <ahmad> 0.10.2-1.mga1
+ Revision: 89370
- Update to 0.10.2
- Drop patch0, redundant now that man pages get compressed properl without it
- Replace the deprecated %%py_requires macro with BR python-devel
- Use the upstream %%{python_sitelib} macro
- Don't copy REAME.txt manually, %%doc it instead

* Sun Mar 06 2011 saispo <saispo> 0.10.1-1.mga1
+ Revision: 65239
- imported package ipython

